@@ -4,12 +4,10 @@ use strict;
 
 use LWP::UserAgent;
 use HTTP::Request::Common;
-use HTTP::CookieJar::LWP ();
 use HTML::TreeBuilder;
 use Encode;
-use JSON;
 
-our $VERSION = '1.65_01'; # TRIAL VERSION
+our $VERSION = '1.50'; # VERSION
 
 use vars qw($BLOOMBERG_URL);
 
@@ -18,7 +16,7 @@ $BLOOMBERG_URL = 'https://www.bloomberg.com/quote/';
 sub methods { return (bloomberg => \&bloomberg); }
 
 {
-  my @labels = qw/method name last currency symbol isodate/;
+  my @labels = qw/method last currency symbol isodate/;
 
   sub labels { return (bloomberg => \@labels); }
 }
@@ -28,18 +26,18 @@ sub bloomberg {
   my @symbols = @_;
 
   return unless @symbols;
-  my ($ua, $cj, $reply, $url, %funds, $te, $table, $row, @value_currency, $name);
+  my ($ua, $reply, $url, %funds, $te, $table, $row, @value_currency, $name);
 
   foreach my $symbol (@symbols) {
     $name = $symbol;
     $url  = $BLOOMBERG_URL;
     $url  = $url . $name;
-    $cj   = HTTP::CookieJar::LWP->new;
-    $ua   = LWP::UserAgent->new(cookie_jar => $cj);
+    $ua   = LWP::UserAgent->new;
     my @ns_headers = (
         'User-Agent' => 'Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:67.0) Gecko/20100101 Firefox/67.0', 
         'Referer' => 'https://www.bloomberg.com/',
         'Accept' => '*/*',
+        'Accept-Encoding' => 'br', 
         'Accept-Language' => 'en-US,en;q=0.5',
         'Pragma' => 'no-cache', );
     $reply = $ua->get($url, @ns_headers);
@@ -52,29 +50,19 @@ sub bloomberg {
 
     eval {
       my $tree  = HTML::TreeBuilder->new_from_content(decode_utf8 $reply->content);
-      my $json = encode_utf8 (($tree->look_down(_tag=>'script', 'id'=>'__NEXT_DATA__')->content_list())[0]);
-      my $json_decoded = decode_json $json;
-      my $json_quote = $json_decoded->{'props'}{'pageProps'}{'quote'};
-      my $desc = $json_quote->{'longName'};
-      my $price = $json_quote->{'price'};
-      my $curr  = $json_quote->{'issuedCurrency'};
-      my $date  = $json_quote->{'lastUpdate'};
+      my $price = $tree->look_down(_tag=>'span', 'class'=>'priceText__1853e8a5')->as_text();
+      my $curr  = $tree->look_down(_tag=>'span', 'class'=>'currency__defc7184')->as_text();
+      my $date  = $tree->look_down(_tag=>'div', sub {defined($_[0]->attr('class')) and $_[0]->attr('class') =~ /time__/})->as_text();
 
-      $curr =~ s/.*[(](.*)[)].*/$1/;
       $price =~ s/,//g;
-      if ($curr eq "GBp") {
-        $curr = "GBP";
-        $price = $price / 100;
-      }
-      $date = $1 if $date =~ m|([0-9]{4}-[0-9]{2}-[0-9]{2})T.*|;
+      $date = $1 if $date =~ m|([0-9]{1,2}/[0-9]{1,2}/[0-9]{4})|;
 
       $funds{$name, 'method'}   = 'bloomberg';
-      $funds{$name, 'name'}     = $desc;
       $funds{$name, 'last'}     = $price;
       $funds{$name, 'currency'} = $curr;
       $funds{$name, 'symbol'}   = $name;
 
-      $quoter->store_date(\%funds, $name, {isodate => $date});
+      $quoter->store_date(\%funds, $name, {usdate => $date});
 
       $funds{$name, 'success'}  = 1;
     };
@@ -114,7 +102,7 @@ The security string must match the format expected by the site, such as
 
 =head1 LABELS RETURNED
 
-Labels returned by this module include: name, last, currency, symbol, isodate
+Labels returned by this module include: last, currency, symbol, isodate
 
 =head1 SEE ALSO
 
