@@ -25,11 +25,7 @@ use if DEBUG, 'Smart::Comments';
 
 use JSON;
 
-our $VERSION = '1.68_01'; # TRIAL VERSION
-
-sub parameters {
-  return ('API_KEY');
-}
+our $VERSION = '1.50'; # VERSION
 
 sub new
 {
@@ -60,13 +56,8 @@ sub multipliers
   my $url = 'https://www.alphavantage.co/query?function=CURRENCY_EXCHANGE_RATE';
   my $try_cnt = 0;
   my $json_data;
-  my $rate;
   do {
     $try_cnt += 1;
-#   AlphaVantage is limiting free/basic api use to one query per second.
-#   sleep 2 ensures a query for currency exchange is not immediately
-#   following a price query.
-    sleep 2;
     my $reply = $ua->get($url
         . '&from_currency=' . ${from}
         . '&to_currency=' . ${to}
@@ -86,22 +77,14 @@ sub multipliers
     sleep (20) if (($try_cnt < 5) && ($json_data->{'Note'}));
   } while (($try_cnt < 5) && ($json_data->{'Note'}));
 
-  if( !$json_data->{'Realtime Currency Exchange Rate'} ) {
-    ### No data in JSON
-	  $rate = 0.0;
-  } else {
-  $rate =
-    $json_data->{'Realtime Currency Exchange Rate'}->{'5. Exchange Rate'};
-  }
-
-  ### Rate from JSON: $rate
+  my $rate = $json_data->{'Realtime Currency Exchange Rate'}->{'5. Exchange Rate'};
 
   return unless $rate + 0;
 
   # For small rates, request the inverse 
   if ($rate < 0.001) {
     ### Rate is too small, requesting inverse : $rate
-    my ($a, $b) = $this->multipliers($ua, $to, $from);
+    my ($a, $b) = $this->multipliers($ua, $from, $to);
     return ($b, $a);
   }
 
