@@ -28,9 +28,9 @@ use JSON qw( decode_json );
 use String::Util qw(trim);
 use Scalar::Util qw(looks_like_number);
 
-our $VERSION = '1.68_01'; # TRIAL VERSION
+our $VERSION = '1.50'; # VERSION
 
-our @labels = qw/last date isodate symbol/;
+our @labels = qw/last date isodate/;
 
 sub labels {
   return ( six => \@labels );
@@ -71,10 +71,9 @@ sub six {
       my %metamap   = map {$metacols[$_] => $_} (0 .. $#metacols);
       my $metarow   = $metadata->{rowData}->[0];
 
-      $info{$symbol, 'symbol'}   = $metarow->[$metamap{ValorSymbol}];
       $info{$symbol, 'isin'}     = $metarow->[$metamap{ISIN}];
       $info{$symbol, 'name'}     = $metarow->[$metamap{IssuerNameFull}];
-      $info{$symbol, 'currency'} = $metarow->[$metamap{TradingBaseCurrency}];
+      $info{$symbol, 'currency'} = $metarow->[$metamap{NominalCurrency}];
 
       $quoter->store_date(\%info, $symbol, {isodate => $metarow->[$metamap{MarketDate}]});
 
@@ -94,7 +93,6 @@ sub six {
       $info{$symbol, 'high'}    = $datarow->[$datamap{DailyHighPrice}] if $datarow->[$datamap{DailyHighPrice}];
       $info{$symbol, 'low'}     = $datarow->[$datamap{DailyLowPrice}]  if $datarow->[$datamap{DailyLowPrice}];
       $info{$symbol, 'open'}    = $datarow->[$datamap{OpeningPrice}]   if $datarow->[$datamap{OpeningPrice}];
-      $info{$symbol, 'last'}    = $datarow->[$datamap{ClosingPrice}]   if $datarow->[$datamap{ClosingPrice}];
       $info{$symbol, 'volume'}  = $datarow->[$datamap{TotalVolume}]    if $datarow->[$datamap{TotalVolume}];
       $info{$symbol, 'success'} = 1;
     };
